Index: /trunk/src/VBox/Frontends/VirtualBox/src/converter/UIConverterBackendGlobal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/converter/UIConverterBackendGlobal.cpp	(revision 60457)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/converter/UIConverterBackendGlobal.cpp	(revision 60458)
@@ -1105,7 +1105,7 @@
     keys << "Active";  values << EventHandlingType_Active;
     keys << "Passive"; values << EventHandlingType_Passive;
     /* Active type for unknown words: */
     if (!keys.contains(strEventHandlingType, Qt::CaseInsensitive))
-        return EventHandlingType_Active;
+        return EventHandlingType_Passive;
     /* Corresponding type for known words: */
     return values.at(keys.indexOf(QRegExp(strEventHandlingType, Qt::CaseInsensitive)));
@@ -1105,7 +1105,7 @@
     keys << "Active";  values << EventHandlingType_Active;
     keys << "Passive"; values << EventHandlingType_Passive;
-    /* Active type for unknown words: */
+    /* Passive type for unknown words: */
     if (!keys.contains(strEventHandlingType, Qt::CaseInsensitive))
